==> nextcloud-30.0.16.tgz: nextcloud/apps/systemtags/l10n/be.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Сістэмны тэг %1$s дададзены сістэмай",
    "Added system tag {systemtag}" : "Дададзены сістэмны тэг {systemtag}",
    "Added system tag %1$s" : "Дададзены сістэмны тэг %1$s",
    "%1$s added system tag %2$s" : "%1$s дадаў(-ла) сістэмны тэг %2$s",
    "{actor} added system tag {systemtag}" : "{actor} дадаў(-ла) сістэмны тэг {systemtag}",
    "System tag %1$s removed by the system" : "Сістэмны тэг %1$s выдалены сістэмай",
    "Removed system tag {systemtag}" : "Выдалены сістэмны тэг {systemtag}",
    "Removed system tag %1$s" : "Выдалены сістэмны тэг %1$s",
    "%1$s removed system tag %2$s" : "%1$s выдаліў(-ла) сістэмны тэг %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} выдаліў(-ла) сістэмны тэг {systemtag}",
    "You created system tag %1$s" : "Вы стварылі сістэмны тэг %1$s",
    "You created system tag {systemtag}" : "Вы стварылі сістэмны тэг {systemtag}",
    "%1$s created system tag %2$s" : "%1$s стварыў(-ла) сістэмны тэг %2$s",
    "{actor} created system tag {systemtag}" : "{actor} стварыў(-ла) сістэмны тэг {systemtag}",
    "You deleted system tag %1$s" : "Вы выдалілі сістэмны тэг %1$s",
    "You deleted system tag {systemtag}" : "Вы выдалілі сістэмны тэг {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s выдаліў(-ла) сістэмны тэг %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} выдаліў(-ла) сістэмны тэг {systemtag}",
    "You updated system tag %2$s to %1$s" : "Вы змянілі сістэмны тэг %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Вы змянілі сістэмны тэг {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s змяніў(-ла) сістэмны тэг %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} змяніў(-ла) сістэмны тэг {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Сістэмны тэг %2$s быў дададзены да %1$s сістэмай",
    "System tag {systemtag} was added to {file} by the system" : "Сістэмны тэг {systemtag} быў дададзены да {file} сістэмай",
    "You added system tag %2$s to %1$s" : "Вы дадалі сістэмны тэг %2$s да %1$s",
    "You added system tag {systemtag} to {file}" : "Вы дадалі сістэмны тэг {systemtag} да {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s дадаў(-ла) сістэмны тэг %3$s да %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} дадаў(-ла) сістэмны тэг {systemtag} да {file}",
    "System tag %2$s was removed from %1$s by the system" : "Сістэмны тэг %2$s быў выдалены з %1$s сістэмай",
    "System tag {systemtag} was removed from {file} by the system" : "Сістэмны тэг {systemtag} быў выдалены з {file} сістэмай",
    "You removed system tag %2$s from %1$s" : "Вы выдалілі сістэмны тэг %2$s з %1$s",
    "You removed system tag {systemtag} from {file}" : "Вы выдалілі сістэмны тэг {systemtag} з {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s выдаліў(-ла) сістэмны тэг %3$s з %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} выдаліў(-ла) сістэмны тэг {systemtag} з {file}",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Сістэмныя тэгі</strong> файла былі зменены",
    "Files" : "Файлы",
    "Tags" : "Тэгі",
    "Collaborative tags" : "Супольныя тэгі",
    "Invisible" : "Нябачны",
    "Created tag" : "Створаны тэг",
    "Failed to create tag" : "Не ўдалося стварыць тэг",
    "Updated tag" : "Зменены тэг",
    "Failed to update tag" : "Не ўдалося змяніць тэг",
    "Deleted tag" : "Выдалены тэг",
    "Failed to delete tag" : "Не ўдалося выдаліць тэг",
    "Tag name" : "Назва тэга",
    "Create" : "Стварыць",
    "Update" : "Абнавіць",
    "Delete" : "Выдаліць",
    "Reset" : "Скінуць",
    "Loading …" : "Загрузка …",
    "Manage tags" : "Кіраванне тэгамі",
    "Change tag color" : "Змяніць колер тэга",
    "Create new tag" : "Стварыйь новы тэг",
    "Cancel" : "Скасаваць",
    "Apply" : "Ужыць",
    "Open in Files" : "Адкрыць у Файлах",
    "List of tags and their associated files and folders." : "Спіс тэгаў і звязаных з імі файлаў і папак.",
    "No tags found" : "Тэгі не знойдзены",
    "Tags you have created will show up here." : "Тут будуць паказвацца створаныя вамі тэгі.",
    "Apply changes" : "Ужыць змены"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/systemtags/l10n/be.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Сістэмны тэг %1$s дададзены сістэмай",
    "Added system tag {systemtag}" : "Дададзены сістэмны тэг {systemtag}",
    "Added system tag %1$s" : "Дададзены сістэмны тэг %1$s",
    "%1$s added system tag %2$s" : "%1$s дадаў(-ла) сістэмны тэг %2$s",
    "{actor} added system tag {systemtag}" : "{actor} дадаў(-ла) сістэмны тэг {systemtag}",
    "System tag %1$s removed by the system" : "Сістэмны тэг %1$s выдалены сістэмай",
    "Removed system tag {systemtag}" : "Выдалены сістэмны тэг {systemtag}",
    "Removed system tag %1$s" : "Выдалены сістэмны тэг %1$s",
    "%1$s removed system tag %2$s" : "%1$s выдаліў(-ла) сістэмны тэг %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} выдаліў(-ла) сістэмны тэг {systemtag}",
    "You created system tag %1$s" : "Вы стварылі сістэмны тэг %1$s",
    "You created system tag {systemtag}" : "Вы стварылі сістэмны тэг {systemtag}",
    "%1$s created system tag %2$s" : "%1$s стварыў(-ла) сістэмны тэг %2$s",
    "{actor} created system tag {systemtag}" : "{actor} стварыў(-ла) сістэмны тэг {systemtag}",
    "You deleted system tag %1$s" : "Вы выдалілі сістэмны тэг %1$s",
    "You deleted system tag {systemtag}" : "Вы выдалілі сістэмны тэг {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s выдаліў(-ла) сістэмны тэг %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} выдаліў(-ла) сістэмны тэг {systemtag}",
    "You updated system tag %2$s to %1$s" : "Вы змянілі сістэмны тэг %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Вы змянілі сістэмны тэг {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s змяніў(-ла) сістэмны тэг %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} змяніў(-ла) сістэмны тэг {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Сістэмны тэг %2$s быў дададзены да %1$s сістэмай",
    "System tag {systemtag} was added to {file} by the system" : "Сістэмны тэг {systemtag} быў дададзены да {file} сістэмай",
    "You added system tag %2$s to %1$s" : "Вы дадалі сістэмны тэг %2$s да %1$s",
    "You added system tag {systemtag} to {file}" : "Вы дадалі сістэмны тэг {systemtag} да {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s дадаў(-ла) сістэмны тэг %3$s да %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} дадаў(-ла) сістэмны тэг {systemtag} да {file}",
    "System tag %2$s was removed from %1$s by the system" : "Сістэмны тэг %2$s быў выдалены з %1$s сістэмай",
    "System tag {systemtag} was removed from {file} by the system" : "Сістэмны тэг {systemtag} быў выдалены з {file} сістэмай",
    "You removed system tag %2$s from %1$s" : "Вы выдалілі сістэмны тэг %2$s з %1$s",
    "You removed system tag {systemtag} from {file}" : "Вы выдалілі сістэмны тэг {systemtag} з {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s выдаліў(-ла) сістэмны тэг %3$s з %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} выдаліў(-ла) сістэмны тэг {systemtag} з {file}",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Сістэмныя тэгі</strong> файла былі зменены",
    "Files" : "Файлы",
    "Tags" : "Тэгі",
    "Collaborative tags" : "Супольныя тэгі",
    "Invisible" : "Нябачны",
    "Created tag" : "Створаны тэг",
    "Failed to create tag" : "Не ўдалося стварыць тэг",
    "Updated tag" : "Зменены тэг",
    "Failed to update tag" : "Не ўдалося змяніць тэг",
    "Deleted tag" : "Выдалены тэг",
    "Failed to delete tag" : "Не ўдалося выдаліць тэг",
    "Collaborative tags …" : "Супольныя тэгі …",
    "Tag name" : "Назва тэга",
    "Create" : "Стварыць",
    "Update" : "Абнавіць",
    "Delete" : "Выдаліць",
    "Reset" : "Скінуць",
    "Loading …" : "Загрузка …",
    "Only admins can create new tags" : "Толькі адміністратары могуць ствараць новыя тэгі",
    "Manage tags" : "Кіраванне тэгамі",
    "Change tag color" : "Змяніць колер тэга",
    "Create new tag" : "Стварыць новы тэг",
    "Cancel" : "Скасаваць",
    "Apply" : "Ужыць",
    "Failed to load tags" : "Не ўдалося загрузіць тэгі",
    "Loading collaborative tags …" : "Загрузка супольных тэгаў …",
    "No tags to select, type to create a new tag" : "Няма тэгаў для выбару, увядзіце тэкст, каб стварыць новы тэг",
    "Open in Files" : "Адкрыць у Файлах",
    "List of tags and their associated files and folders." : "Спіс тэгаў і звязаных з імі файлаў і папак.",
    "No tags found" : "Тэгі не знойдзены",
    "Tags you have created will show up here." : "Тут будуць паказвацца створаныя вамі тэгі.",
    "Loading …" : "Загрузка …",
    "Apply changes" : "Ужыць змены"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
